@@ -1,8 +1,11 @@
 from .IAbortable import IAbortable
 from .IAcquisition import IAcquisition
-from .IAltAzMount import IAltAzMount
+from .IAltAz import IAltAz
+from .ILatLon import ILatLon
+from .IAltAzOffsets import IAltAzOffsets
 from .IAutoFocus import IAutoFocus
 from .IAutoGuiding import IAutoGuiding
+from .IAutonomous import IAutonomous
 from .ICalibrate import ICalibrate
 from .ICamera import ICamera
 from .ICameraBinning import ICameraBinning
@@ -11,7 +14,6 @@ from .IConfigProvider import IConfigProvider
 from .ICooling import ICooling
 from .ICoordinatesQuery import ICoordinatesQuery
 from .IDome import IDome
-from .IEquatorialMount import IEquatorialMount
 from .IFilters import IFilters
 from .IFitsHeaderProvider import IFitsHeaderProvider
 from .IFlatField import IFlatField
@@ -19,6 +21,8 @@ from .IFocusModel import IFocusModel
 from .IFocuser import IFocuser
 from .IMotion import IMotion
 from .IPipeline import IPipeline
+from .IRaDec import IRaDec
+from .IRaDecOffsets import IRaDecOffsets
 from .IReady import IReady
 from .IRoof import IRoof
 from .IRotation import IRotation
@@ -26,6 +30,7 @@ from .IRunnable import IRunnable
 from .IScriptRunner import IScriptRunner
 from .ISettings import ISettings
 from .IStoppable import IStoppable
+from .ISyncTarget import ISyncTarget
 from .ITelescope import ITelescope
 from .ITemperatures import ITemperatures
 from .IWeather import IWeather
