@@ -1,4 +1,4 @@
 from .basecamera import BaseCamera
-from .adaptive import AdaptiveExpTimeCamera
+from .adaptive import AdaptiveCamera
 from .dummycamera import DummyCamera
 from .flatfieldtestcamera import FlatFieldTestCamera
