@@ -1,22 +1,19 @@
-import io
 import logging
-
-import typing
 from py_expression_eval import Parser
 import pandas as pd
-import lmfit
 import numpy as np
 
 from pyobs import PyObsModule
+from pyobs.mixins import TableStorageMixin
 from pyobs.modules import timeout
-from pyobs.interfaces import IFocuser, IMotion, IWeather, ITemperatures, IFocusModel, IFilters
+from pyobs.interfaces import IFocuser, IWeather, ITemperatures, IFocusModel, IFilters
 from pyobs.events import FocusFoundEvent, FilterChangedEvent
 from pyobs.utils.time import Time
 
 log = logging.getLogger(__name__)
 
 
-class FocusModel(PyObsModule, IFocusModel):
+class FocusModel(PyObsModule, TableStorageMixin, IFocusModel):
     """A focus model that is automatically applied to an IFocuser.
 
     If, e.g., the model is defined as:
@@ -53,7 +50,7 @@ class FocusModel(PyObsModule, IFocusModel):
 
     def __init__(self, focuser: str = None, weather: str = None, interval: int = 300, temperatures: dict = None,
                  model: str = None, coefficients: dict = None, update: bool = False,
-                 measurements: str = '/pyobs/focus_model.csv', min_measurements: int = 10, enabled: bool = True,
+                 log_file: str = None, min_measurements: int = 10, enabled: bool = True,
                  temp_sensor: str = 'average.temp', default_filter: str = None, filter_offsets: dict = None,
                  filter_wheel: str = None, *args, **kwargs):
         """Initialize a focus model.
@@ -65,7 +62,7 @@ class FocusModel(PyObsModule, IFocusModel):
             model: Focus model to use.
             coefficients: Coefficients in model, mainly used when updating it.
             update: Whether to update the model on new focus values.
-            measurements: Path to file containing all focus measurements.
+            log_file: Path to file containing all focus measurements.
             min_measurements: Minimum number of measurements to update model.
             enabled: If False, no focus is set.
             temp_sensor: Name of sensor at weather station to provide ambient temperature.
@@ -75,6 +72,9 @@ class FocusModel(PyObsModule, IFocusModel):
         """
         PyObsModule.__init__(self, *args, **kwargs)
 
+        # check import
+        import lmfit
+
         # add thread func
         if interval is not None and interval > 0:
             self._add_thread_func(self._run_thread, True)
@@ -110,10 +110,19 @@ class FocusModel(PyObsModule, IFocusModel):
             variables.remove(c)
         log.info('Found variables: %s', ', '.join(variables))
 
-        # load measurements
-        self._measurements_file = measurements
-        self._measurements = None
-        self._load_measurements()
+        # columns for storage
+        storage_columns = {
+            'datetime': str,
+            'focus': float,
+            'error': float,
+            'filter': str,
+            'temp': float
+        }
+        for temp in self._temperatures:
+            storage_columns[temp] = float
+
+        # init table storage and load measurements
+        TableStorageMixin.__init__(self, filename=log_file, columns=storage_columns, reload_always=True)
 
         # update model now?
         if update:
@@ -336,22 +345,8 @@ class FocusModel(PyObsModule, IFocusModel):
         values['datetime'] = Time.now().isot
         values['filter'] = event.filter_name
 
-        # append or new?
-        if self._measurements is None:
-            # use values as new dataframe with one entry
-            log.info('No previous measurements found, starting new file.')
-            self._measurements = pd.DataFrame({k: [v] for k, v in values.items()})
-        else:
-            # append
-            try:
-                self._measurements = self._measurements.append(values, ignore_index=True)
-            except TypeError:
-                # wrong file format?
-                log.error('Possibly wrong file format for %s, please fix or delete it.', self._measurements_file)
-                return
-
-        # write it back
-        self._save_measurements()
+        # append to table storage
+        self._append_to_table_storage(**values)
 
         # finally, calculate new model
         log.info('Re-calculating model...')
@@ -360,40 +355,16 @@ class FocusModel(PyObsModule, IFocusModel):
         # finished
         log.info('Done.')
 
-    def _load_measurements(self):
-        try:
-            # open file with previous measurements
-            log.info('Reading previous measurements...')
-            with self.open_file(self._measurements_file, 'r') as f:
-                # read data and append values
-                self._measurements = pd.read_csv(f, index_col=False)
-
-        except (FileNotFoundError, pd.errors.EmptyDataError):
-            # use values as new dataframe with one entry
-            log.info('No previous measurements found, starting new file.')
-            self._measurements = None
-
-    def _save_measurements(self):
-        # no measurements?
-        if self._measurements is None:
-            return
-
-        # write to file
-        with self.open_file(self._measurements_file, 'w') as f:
-            log.info('Writing measurements to file...')
-            with io.StringIO() as sio:
-                self._measurements.to_csv(sio, index=False)
-                f.write(sio.getvalue().encode('utf8'))
-
     def _calc_focus_model(self):
         """Calculate new focus model from saved entries."""
+        import lmfit
 
         # no coefficients? no model...
-        if not self._coefficients or self._measurements is None:
+        if not self._coefficients or self._table_storage is None:
             return
 
         # only take clear filter images for now
-        data = self._measurements.copy()
+        data = self._table_storage.copy()
 
         # enough measurements?
         if len(data) < self._min_measurements:
@@ -446,7 +417,7 @@ class FocusModel(PyObsModule, IFocusModel):
                 self._coefficients = {k: v for k, v in d.items() if not k.startswith('off_')}
                 self._filter_offsets = {k[4:]: v for k, v in d.items() if k.startswith('off_')}
 
-    def _residuals(self, x: lmfit.Parameters, data: pd.DataFrame):
+    def _residuals(self, x: 'lmfit.Parameters', data: pd.DataFrame):
         """Fit method for model
 
         Args:
