@@ -1,3 +1,3 @@
-from .pointing import PointingMastermind
+from .pointing import PointingSeries
 from .robotic import RoboticMastermind
 from .scheduler import Scheduler
