@@ -2,8 +2,10 @@ import logging
 import threading
 import time
 import numpy as np
+from typing import Union, Type
 
-from pyobs.interfaces import ICamera, ICameraBinning, ICameraWindow, IRoof, ITelescope, IFilters, IAutoGuiding
+from pyobs.interfaces import ICamera, ICameraBinning, ICameraWindow, IRoof, ITelescope, IFilters, IAutoGuiding, \
+    IAcquisition
 from pyobs.robotic.scripts import Script
 from pyobs.utils.threads import Future
 
@@ -14,36 +16,54 @@ log = logging.getLogger(__name__)
 class LcoDefaultScript(Script):
     """Default script for LCO configs."""
 
-    def __init__(self, config: dict, roof: IRoof, telescope: ITelescope, camera: ICamera, filters: IFilters,
-                 autoguider: IAutoGuiding, instruments: dict, *args, **kwargs):
+    def __init__(self, camera: Union[str, ICamera], roof: Union[str, IRoof] = None,
+                 telescope: Union[str, ITelescope] = None, filters: Union[str, IFilters] = None,
+                 autoguider: Union[str, IAutoGuiding] = None, acquisition: Union[str, IAcquisition] = None,
+                 *args, ** kwargs):
         """Initialize a new LCO default script.
 
         Args:
-            config: Config to run
             roof: Roof to use
             telescope: Telescope to use
             camera: Camera to use
             filters: Filter wheel to use
-            instruments: Instruments description from portal
+            autoguider: Autoguider to use
+            acquisition: Acquisition to use
         """
         Script.__init__(self, *args, **kwargs)
 
         # store
-        self.config = config
         self.roof = roof
         self.telescope = telescope
         self.camera = camera
         self.filters = filters
         self.autoguider = autoguider
-        self.instruments = instruments
+        self.acquisition = acquisition
 
         # get image type
         self.image_type = ICamera.ImageType.OBJECT
-        if config['type'] == 'BIAS':
+        if self.configuration['type'] == 'BIAS':
             self.image_type = ICamera.ImageType.BIAS
-        elif config['type'] == 'DARK':
+        elif self.configuration['type'] == 'DARK':
             self.image_type = ICamera.ImageType.DARK
 
+    def _get_proxies(self) -> (IRoof, ITelescope, ICamera, IFilters, IAutoGuiding, IAcquisition):
+        """Get proxies for running the task
+
+        Returns:
+            Proxies for roof, telescope, camera and filter wheel
+
+        Raises:
+            ValueError: If could not get proxies for all modules
+        """
+        roof: IRoof = self._get_proxy(self.roof, IRoof)
+        telescope: ITelescope = self._get_proxy(self.telescope, ITelescope)
+        camera: ICamera = self._get_proxy(self.camera, ICamera)
+        filters: IFilters = self._get_proxy(self.filters, IFilters)
+        autoguider: IAutoGuiding = self._get_proxy(self.autoguider, IAutoGuiding)
+        acquisition: IAcquisition = self._get_proxy(self.acquisition, IAcquisition)
+        return roof, telescope, camera, filters, autoguider, acquisition
+
     def can_run(self) -> bool:
         """Whether this config can currently run.
 
@@ -51,9 +71,36 @@ class LcoDefaultScript(Script):
             True, if script can run now
         """
 
-        # we need an open roof and a working telescope for OBJECT exposures
+        # get proxies
+        roof, telescope, camera, filters, autoguider, acquisition = self._get_proxies()
+
+        # need camera
+        if camera is None:
+            return False
+
+        # for OBJECT exposure we need more
         if self.image_type == ICamera.ImageType.OBJECT:
-            if not self.roof.is_ready().wait() or not self.telescope.is_ready().wait():
+            # we need an open roof and a working telescope
+            if roof is None or not roof.is_ready().wait():
+                return False
+            if telescope is None or not telescope.is_ready().wait():
+                return False
+
+            # we probably need filters and autoguider/acquisition
+            if filters is None:
+                log.warning('No filter module found for task.')
+                return False
+
+            # acquisition?
+            if 'acquisition_config' in self.configuration and 'mode' in self.configuration['acquisition_config'] and \
+                    self.configuration['acquisition_config']['mode'] == 'ON' and acquisition is None:
+                log.warning('No acquisition found for task.')
+                return False
+
+            # guiding?
+            if 'guiding_config' in self.configuration and 'mode' in self.configuration['guiding_config'] and \
+                    self.configuration['guiding_config']['mode'] == 'ON' and autoguider is None:
+                log.warning('No auto guider found for task.')
                 return False
 
         # seems alright
@@ -69,31 +116,48 @@ class LcoDefaultScript(Script):
             InterruptedError: If interrupted
         """
 
+        # get proxies
+        roof, telescope, camera, filters, autoguider, acquisition = self._get_proxies()
+
         # got a target?
-        target = self.config['target']
+        target = self.configuration['target']
         track = None
-        if target['ra'] is not None and target['dec'] is not None:
+        if self.image_type == ICamera.ImageType.OBJECT:
             log.info('Moving to target %s...', target['name'])
-            track = self.telescope.track_radec(target['ra'], target['dec'])
+            track = telescope.move_radec(target['ra'], target['dec'])
+
+        # acquisition?
+        if 'acquisition_config' in self.configuration and 'mode' in self.configuration['acquisition_config'] and \
+                self.configuration['acquisition_config']['mode'] == 'ON':
+            # wait for track
+            track.wait()
+
+            # get exposure time
+            acq = self.configuration['acquisition_config']
+            exp_time = acq['exposure_time'] * 1000 if 'exposure_time' in acq else 2000
+
+            # do acquisition
+            log.info('Performing acquisition...')
+            acquisition.acquire_target(exp_time).wait()
 
         # guiding?
-        if 'guiding_config' in self.config and 'mode' in self.config['guiding_config'] and \
-                self.config['guiding_config']['mode'] == 'ON':
+        if 'guiding_config' in self.configuration and 'mode' in self.configuration['guiding_config'] and \
+                self.configuration['guiding_config']['mode'] == 'ON':
             log.info('Starting auto-guiding...')
-            self.autoguider.start().wait()
+            autoguider.start().wait()
 
         # total (exposure) time done in this config
         self.exptime_done = 0
 
         # get instrument info
-        instrument_type = self.config['instrument_type'].lower()
-        instrument = self.instruments[instrument_type]
+        instrument_type = self.configuration['instrument_type'].lower()
+        instrument = self.task_archive.instruments[instrument_type]
 
         # setting repeat duration depending on config type
         repeat_duration = None
-        if self.config['type'] == 'REPEAT_EXPOSE':
-            if 'repeat_duration' in self.config:
-                repeat_duration = self.config['repeat_duration']
+        if self.configuration['type'] == 'REPEAT_EXPOSE':
+            if 'repeat_duration' in self.configuration:
+                repeat_duration = self.configuration['repeat_duration']
                 log.info('Repeating all instrument configurations for %d seconds.', repeat_duration)
             else:
                 log.error('Type is REPEAT_EXPOSE, but no repeat_duration was set.')
@@ -106,7 +170,7 @@ class LcoDefaultScript(Script):
             ic_start_time = time.time()
 
             # loop instrument configs
-            for ic in self.config['instrument_configs']:
+            for ic in self.configuration['instrument_configs']:
                 self._check_abort(abort_event)
 
                 # get readout mode
@@ -122,19 +186,19 @@ class LcoDefaultScript(Script):
                 set_filter = None
                 if 'optical_elements' in ic and 'filter' in ic['optical_elements']:
                     log.info('Setting filter to %s...', ic['optical_elements']['filter'])
-                    set_filter = self.filters.set_filter(ic['optical_elements']['filter'])
+                    set_filter = filters.set_filter(ic['optical_elements']['filter'])
 
                 # wait for tracking and filter
                 Future.wait_all([track, set_filter])
 
                 # set binning and window
-                if isinstance(self.camera, ICameraBinning):
+                if isinstance(camera, ICameraBinning):
                     binning = readout_mode['params']['binning']
                     log.info('Set binning to %dx%d...', binning, binning)
-                    self.camera.set_binning(binning, binning).wait()
-                if isinstance(self.camera, ICameraWindow):
-                    full_frame = self.camera.get_full_frame().wait()
-                    self.camera.set_window(*full_frame).wait()
+                    camera.set_binning(binning, binning).wait()
+                if isinstance(camera, ICameraWindow):
+                    full_frame = camera.get_full_frame().wait()
+                    camera.set_window(*full_frame).wait()
 
                 # loop images
                 for exp in range(ic['exposure_count']):
@@ -142,8 +206,8 @@ class LcoDefaultScript(Script):
 
                     # do exposures
                     log.info('Exposing %s image %d/%d for %.2fs...',
-                             self.config['type'], exp + 1, ic['exposure_count'], ic['exposure_time'])
-                    self.camera.expose(int(ic['exposure_time'] * 1000), self.image_type).wait()
+                             self.configuration['type'], exp + 1, ic['exposure_count'], ic['exposure_time'])
+                    camera.expose(int(ic['exposure_time'] * 1000), self.image_type).wait()
                     self.exptime_done += ic['exposure_time']
 
             # store duration for all ICs
@@ -164,15 +228,16 @@ class LcoDefaultScript(Script):
                     config_finished = True
 
         # stop auto guiding
-        if 'guiding_config' in self.config and 'mode' in self.config['guiding_config'] and \
-                self.config['guiding_config']['mode'] == 'ON':
+        if 'guiding_config' in self.configuration and 'mode' in self.configuration['guiding_config'] and \
+                self.configuration['guiding_config']['mode'] == 'ON':
             log.info('Stopping auto-guiding...')
-            self.autoguider.stop().wait()
+            autoguider.stop().wait()
 
         # finally, stop telescope
         if not abort_event.is_set():
-            log.info('Stopping telescope...')
-            self.telescope.stop_motion().wait()
+            if self.image_type == ICamera.ImageType.OBJECT:
+                log.info('Stopping telescope...')
+                telescope.stop_motion().wait()
 
     def get_fits_headers(self, namespaces: list = None) -> dict:
         """Returns FITS header for the current status of this module.
@@ -190,7 +255,7 @@ class LcoDefaultScript(Script):
         # which image type?
         if self.image_type == ICamera.ImageType.OBJECT:
             # add object name
-            hdr['OBJECT'] = self.config['target']['name'], 'Name of target'
+            hdr['OBJECT'] = self.configuration['target']['name'], 'Name of target'
 
         # return
         return hdr
