@@ -6,12 +6,17 @@ from pyobs.utils.images import BiasImage, DarkImage, CalibrationImage, Image
 
 class FlatImage(CalibrationImage):
     @staticmethod
-    def create_master(images: List[Image], bias: BiasImage, dark: DarkImage) -> 'DarkImage':
+    def create_master(images: List[Image], bias: BiasImage, dark: DarkImage,
+                      method: Image.CombineMethod = Image.CombineMethod.MEAN) -> 'DarkImage':
         # calibrate
         calibrated = [img.calibrate(bias=bias, dark=dark) for img in images]
 
+        # normalize to mean
+        for img in calibrated:
+            img.data /= np.mean(img.data)
+
         # average
-        average = FlatImage.average(calibrated)
+        average = FlatImage.combine(calibrated, method=method)
 
         # divide flat by its mean
         average.data /= np.mean(average.data)
